define('dummy/app', ['exports', 'ember', 'ember/resolver', 'ember/load-initializers', './config/environment'], function (exports, Ember, Resolver, loadInitializers, config) {

  'use strict';

  Ember['default'].MODEL_FACTORY_INJECTIONS = true;

  var App = Ember['default'].Application.extend({
    modulePrefix: config['default'].modulePrefix,
    podModulePrefix: config['default'].podModulePrefix,
    Resolver: Resolver['default']
  });

  loadInitializers['default'](App, config['default'].modulePrefix);

  exports['default'] = App;

});
define('dummy/components/growl-instance', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  exports['default'] = Ember['default'].Component.extend({
    classNames: ["growl-instance"],
    classNameBindings: ["type"],
    type: (function () {
      return this.get("notification.options.type");
    }).property(),
    click: function () {
      this.destroyAlert();
    },
    didInsertElement: function () {
      if (this.get("notification.options.fadeIn")) {
        this.$().hide().fadeIn();
      }

      if (this.get("notification.options.twitch")) {
        var el = this.$(),
            maxDegree = 1,
            negative;
        var interval = window.setInterval(function () {
          negative = negative ? "" : "-";
          el.css("transform", "rotate(" + negative + maxDegree + "deg)");
        }, 75);
        Ember['default'].run.later(function () {
          el.css("transform", "rotate(0deg)");
          window.clearInterval(interval);
        }, 400);
      }

      // unless a click-to-dismiss is required we auto close
      if (!this.get("notification.options.clickToDismiss")) {
        Ember['default'].run.later(this, this.destroyAlert, this.get("notification.options.closeIn"));
      }
    },
    destroyAlert: function () {
      var self = this;
      if (this.$()) {
        this.$().fadeOut(Ember['default'].run(this, function () {
          // send the action on up so the manager can remove this item from array
          self.sendAction("action", self.get("notification"));
        }));
      } else {
        self.sendAction("action", self.get("notification"));
      }
    },
    actions: {
      dismiss: function () {
        // a close button has been clicked
        this.destroyAlert();
      }
    }
  });

});
define('dummy/components/growl-manager', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  exports['default'] = Ember['default'].Component.extend({
    classNames: ["growl-manager"],
    actions: {
      dismiss: function (notification) {
        this.get("notifications").removeObject(notification);
      }
    }
  });

});
define('dummy/initializers/app-version', ['exports', '../config/environment', 'ember'], function (exports, config, Ember) {

  'use strict';

  var classify = Ember['default'].String.classify;

  exports['default'] = {
    name: "App Version",
    initialize: function (container, application) {
      var appName = classify(application.toString());
      Ember['default'].libraries.register(appName, config['default'].APP.version);
    }
  };

});
define('dummy/initializers/export-application-global', ['exports', 'ember', '../config/environment'], function (exports, Ember, config) {

  'use strict';

  exports.initialize = initialize;

  function initialize(container, application) {
    var classifiedName = Ember['default'].String.classify(config['default'].modulePrefix);

    if (config['default'].exportApplicationGlobal) {
      window[classifiedName] = application;
    }
  };

  exports['default'] = {
    name: "export-application-global",

    initialize: initialize
  };

});
define('dummy/initializers/growl', ['exports', '../services/growl'], function (exports, Growl) {

  'use strict';

  exports['default'] = {
    name: "growl",
    initialize: function (container, app) {
      Growl['default'].reopenClass({
        container: container
      });

      app.register("growl:main", Growl['default']);
      app.inject("route", "growl", "growl:main");
      app.inject("controller", "growl", "growl:main");
    }
  };

});
define('dummy/router', ['exports', 'ember', './config/environment'], function (exports, Ember, config) {

  'use strict';

  var Router = Ember['default'].Router.extend({
    location: config['default'].locationType
  });

  Router.map(function () {});

  exports['default'] = Router;

});
define('dummy/routes/application', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  exports['default'] = Ember['default'].Route.extend({
    actions: {
      showInfo: function () {
        this.growl.info("This is an info message.");
      },
      showAlert: function () {
        this.growl.alert("This is an alert.");
      },
      showAlertTwitch: function () {
        this.growl.alert("This message will twitch.<br>Displayed via: <code>this.growl.alert('This message will twitch.', {twitch: true});</code>", { twitch: true });
      },
      showThreeAlerts: function () {
        for (var i = 0; i < 3; i++) {
          this.growl.alert("Identical messages will not display additional growl notifications.");
        }
      },
      showError: function () {
        this.growl.error("This is the error message.<br>Displayed via: <code>this.growl.error('This is the error message.');</code>");
      },
      showErrorClick: function () {
        this.growl.error("You must click to dismiss this error message.", { clickToDismiss: true });
      }
    }
  });

});
define('dummy/services/growl', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  exports['default'] = Ember['default'].Object.extend({
    notifications: Ember['default'].A(),
    error: function (context, opts) {
      opts = opts || {};
      opts.type = "error";
      this._notify.call(this, context, opts);
    },
    alert: function (context, opts) {
      opts = opts || {};
      opts.type = "alert";
      this._notify.call(this, context, opts);
    },
    info: function (context, opts) {
      opts = opts || {};
      opts.type = "info";
      this._notify.call(this, context, opts);
    },

    _notify: function (context, opts) {
      // default options
      var options = {
        type: "error",
        fadeIn: true,
        closeIn: 5000, // automatically close in 5 seconds.
        clickToDismiss: false, // stay open until it receives a click?
        twitch: false
      };

      Ember['default'].merge(options, opts);

      // if the developer passed an identical message then we just update
      // the open notification balloon options
      var existing = this.get("notifications").findBy("content", context);
      if (existing) {
        return;
      }

      var notification = Ember['default'].ObjectProxy.extend({
        // {{notification.content}} for a string or {{notification.foo}} if you
        // pass an object from a route via this.growl.error({foo: 'bar'});
        content: context,
        options: options,
        updated: 0,
        isInfo: (function () {
          return options.type === "info";
        }).property(),
        isAlert: (function () {
          return options.type === "alert";
        }).property(),
        isError: (function () {
          return options.type === "error";
        }).property()
      }).create();

      this.get("notifications").pushObject(notification);
    }
  });

});
define('dummy/templates/application', ['exports'], function (exports) {

  'use strict';

  exports['default'] = Ember.Handlebars.template({"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1, helperMissing=helpers.helperMissing, escapeExpression=this.escapeExpression, buffer = '';
    data.buffer.push("\n");
    data.buffer.push(escapeExpression(((helpers['growl-manager'] || (depth0 && depth0['growl-manager']) || helperMissing).call(depth0, {"name":"growl-manager","hash":{
      'notifications': ("growl.notifications")
    },"hashTypes":{'notifications': "ID"},"hashContexts":{'notifications': depth0},"types":[],"contexts":[],"data":data}))));
    data.buffer.push("\n\n<h2 id='title'>Welcome to Ember.js</h2>\n\n<ul>\n  <li><button class=\"info\" ");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "showInfo", {"name":"action","hash":{},"hashTypes":{},"hashContexts":{},"types":["STRING"],"contexts":[depth0],"data":data})));
    data.buffer.push(">Show an info message</button></li>\n  <li><button class=\"alert\" ");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "showAlert", {"name":"action","hash":{},"hashTypes":{},"hashContexts":{},"types":["STRING"],"contexts":[depth0],"data":data})));
    data.buffer.push(">Show an alert</button></li>\n  <li><button class=\"twitch\" ");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "showAlertTwitch", {"name":"action","hash":{},"hashTypes":{},"hashContexts":{},"types":["STRING"],"contexts":[depth0],"data":data})));
    data.buffer.push(">Show an alert that twitches</button></li>\n  <li><button class=\"three\" ");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "showThreeAlerts", {"name":"action","hash":{},"hashTypes":{},"hashContexts":{},"types":["STRING"],"contexts":[depth0],"data":data})));
    data.buffer.push(">Show identical alerts in a for loop</button></li>\n  <li><button class=\"error\" ");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "showError", {"name":"action","hash":{},"hashTypes":{},"hashContexts":{},"types":["STRING"],"contexts":[depth0],"data":data})));
    data.buffer.push(">Show an error</button></li>\n  <li><button class=\"dismiss\" ");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "showErrorClick", {"name":"action","hash":{},"hashTypes":{},"hashContexts":{},"types":["STRING"],"contexts":[depth0],"data":data})));
    data.buffer.push(">An error that must be clicked</button></li>\n</ul>\n\n<div class=\"boxed\">\n");
    stack1 = helpers._triageMustache.call(depth0, "outlet", {"name":"_triageMustache","hash":{},"hashTypes":{},"hashContexts":{},"types":["ID"],"contexts":[depth0],"data":data});
    if (stack1 != null) { data.buffer.push(stack1); }
    data.buffer.push("\n</div>\n");
    return buffer;
  },"useData":true})

});
define('dummy/templates/components/growl-instance', ['exports'], function (exports) {

  'use strict';

  exports['default'] = Ember.Handlebars.template({"1":function(depth0,helpers,partials,data) {
    data.buffer.push("  <img src=\"../img/error.svg\" alt=\"Error\"/>\n");
    },"3":function(depth0,helpers,partials,data) {
    data.buffer.push("  <img src=\"../img/alert.svg\" alt=\"Alert\"/>\n");
    },"5":function(depth0,helpers,partials,data) {
    data.buffer.push("  <img src=\"../img/info.svg\" alt=\"Info\"/>\n");
    },"7":function(depth0,helpers,partials,data) {
    data.buffer.push("    <h1>Uh oh.</h1>\n");
    },"9":function(depth0,helpers,partials,data) {
    data.buffer.push("    <h1>Attention!</h1>\n");
    },"11":function(depth0,helpers,partials,data) {
    data.buffer.push("    <h1>Hey!</h1>\n");
    },"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1, helperMissing=helpers.helperMissing, escapeExpression=this.escapeExpression, buffer = '';
    data.buffer.push("\n");
    stack1 = ((helpers.unboundIf || (depth0 && depth0.unboundIf) || helperMissing).call(depth0, "notification.isError", {"name":"unboundIf","hash":{},"hashTypes":{},"hashContexts":{},"fn":this.program(1, data),"inverse":this.noop,"types":["ID"],"contexts":[depth0],"data":data}));
    if (stack1 != null) { data.buffer.push(stack1); }
    data.buffer.push("\n");
    stack1 = ((helpers.unboundIf || (depth0 && depth0.unboundIf) || helperMissing).call(depth0, "notification.isAlert", {"name":"unboundIf","hash":{},"hashTypes":{},"hashContexts":{},"fn":this.program(3, data),"inverse":this.noop,"types":["ID"],"contexts":[depth0],"data":data}));
    if (stack1 != null) { data.buffer.push(stack1); }
    data.buffer.push("\n");
    stack1 = ((helpers.unboundIf || (depth0 && depth0.unboundIf) || helperMissing).call(depth0, "notification.isInfo", {"name":"unboundIf","hash":{},"hashTypes":{},"hashContexts":{},"fn":this.program(5, data),"inverse":this.noop,"types":["ID"],"contexts":[depth0],"data":data}));
    if (stack1 != null) { data.buffer.push(stack1); }
    data.buffer.push("\n<div class=\"message-area\">\n");
    stack1 = ((helpers.unboundIf || (depth0 && depth0.unboundIf) || helperMissing).call(depth0, "notification.isError", {"name":"unboundIf","hash":{},"hashTypes":{},"hashContexts":{},"fn":this.program(7, data),"inverse":this.noop,"types":["ID"],"contexts":[depth0],"data":data}));
    if (stack1 != null) { data.buffer.push(stack1); }
    data.buffer.push("\n");
    stack1 = ((helpers.unboundIf || (depth0 && depth0.unboundIf) || helperMissing).call(depth0, "notification.isAlert", {"name":"unboundIf","hash":{},"hashTypes":{},"hashContexts":{},"fn":this.program(9, data),"inverse":this.noop,"types":["ID"],"contexts":[depth0],"data":data}));
    if (stack1 != null) { data.buffer.push(stack1); }
    data.buffer.push("\n");
    stack1 = ((helpers.unboundIf || (depth0 && depth0.unboundIf) || helperMissing).call(depth0, "notification.isInfo", {"name":"unboundIf","hash":{},"hashTypes":{},"hashContexts":{},"fn":this.program(11, data),"inverse":this.noop,"types":["ID"],"contexts":[depth0],"data":data}));
    if (stack1 != null) { data.buffer.push(stack1); }
    data.buffer.push("\n  <div class=\"message\">\n    ");
    data.buffer.push(escapeExpression(helpers._triageMustache.call(depth0, "notification.content", {"name":"_triageMustache","hash":{
      'unescaped': ("true")
    },"hashTypes":{'unescaped': "STRING"},"hashContexts":{'unescaped': depth0},"types":["ID"],"contexts":[depth0],"data":data})));
    data.buffer.push("\n  </div>\n</div>\n");
    return buffer;
  },"useData":true})

});
define('dummy/templates/components/growl-manager', ['exports'], function (exports) {

  'use strict';

  exports['default'] = Ember.Handlebars.template({"1":function(depth0,helpers,partials,data) {
    var helperMissing=helpers.helperMissing, escapeExpression=this.escapeExpression, buffer = '';
    data.buffer.push("  ");
    data.buffer.push(escapeExpression(((helpers['growl-instance'] || (depth0 && depth0['growl-instance']) || helperMissing).call(depth0, {"name":"growl-instance","hash":{
      'notification': ("notification"),
      'action': ("dismiss")
    },"hashTypes":{'notification': "ID",'action': "STRING"},"hashContexts":{'notification': depth0,'action': depth0},"types":[],"contexts":[],"data":data}))));
    data.buffer.push("\n");
    return buffer;
  },"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1, buffer = '';
    data.buffer.push("\n");
    stack1 = helpers.each.call(depth0, "notification", "in", "notifications", {"name":"each","hash":{},"hashTypes":{},"hashContexts":{},"fn":this.program(1, data),"inverse":this.noop,"types":["ID","ID","ID"],"contexts":[depth0,depth0,depth0],"data":data});
    if (stack1 != null) { data.buffer.push(stack1); }
    return buffer;
  },"useData":true})

});
define('dummy/tests/acceptance/main-test', ['ember', '../helpers/start-app'], function (Ember, startApp) {

  'use strict';

  var App;

  module("Acceptance: Main", {
    setup: function () {
      App = startApp['default']();
    },
    teardown: function () {
      Ember['default'].run(App, "destroy");
    }
  });

  test("testing that a growl message is added and closes when clicked", function () {
    visit("/");

    $(".info").click();
    equal(find(".growl-instance").length, 1, "The component's element exists");
    $(".growl-instance").click();
    equal(find(".growl-instance").length, 0, "The info message has closed");

    $(".alert").click();
    equal(find(".growl-instance").length, 1, "The alert message element exists");
    Ember['default'].run.later(function () {
      equal(find(".growl-instance").length, 0, "The alert message has closed via timeout");
    }, 6000);
  });

});
define('dummy/tests/acceptance/main-test.jshint', function () {

  'use strict';

  module('JSHint - acceptance');
  test('acceptance/main-test.js should pass jshint', function() { 
    ok(true, 'acceptance/main-test.js should pass jshint.'); 
  });

});
define('dummy/tests/app.jshint', function () {

  'use strict';

  module('JSHint - .');
  test('app.js should pass jshint', function() { 
    ok(true, 'app.js should pass jshint.'); 
  });

});
define('dummy/tests/helpers/resolver', ['exports', 'ember/resolver', '../../config/environment'], function (exports, Resolver, config) {

  'use strict';

  var resolver = Resolver['default'].create();

  resolver.namespace = {
    modulePrefix: config['default'].modulePrefix,
    podModulePrefix: config['default'].podModulePrefix
  };

  exports['default'] = resolver;

});
define('dummy/tests/helpers/resolver.jshint', function () {

  'use strict';

  module('JSHint - helpers');
  test('helpers/resolver.js should pass jshint', function() { 
    ok(true, 'helpers/resolver.js should pass jshint.'); 
  });

});
define('dummy/tests/helpers/start-app', ['exports', 'ember', '../../app', '../../router', '../../config/environment'], function (exports, Ember, Application, Router, config) {

  'use strict';



  exports['default'] = startApp;
  function startApp(attrs) {
    var application;

    var attributes = Ember['default'].merge({}, config['default'].APP);
    attributes = Ember['default'].merge(attributes, attrs); // use defaults, but you can override;

    Ember['default'].run(function () {
      application = Application['default'].create(attributes);
      application.setupForTesting();
      application.injectTestHelpers();
    });

    return application;
  }

});
define('dummy/tests/helpers/start-app.jshint', function () {

  'use strict';

  module('JSHint - helpers');
  test('helpers/start-app.js should pass jshint', function() { 
    ok(true, 'helpers/start-app.js should pass jshint.'); 
  });

});
define('dummy/tests/router.jshint', function () {

  'use strict';

  module('JSHint - .');
  test('router.js should pass jshint', function() { 
    ok(true, 'router.js should pass jshint.'); 
  });

});
define('dummy/tests/routes/application.jshint', function () {

  'use strict';

  module('JSHint - routes');
  test('routes/application.js should pass jshint', function() { 
    ok(true, 'routes/application.js should pass jshint.'); 
  });

});
define('dummy/tests/test-helper', ['./helpers/resolver', 'ember-qunit'], function (resolver, ember_qunit) {

	'use strict';

	ember_qunit.setResolver(resolver['default']);

});
define('dummy/tests/test-helper.jshint', function () {

  'use strict';

  module('JSHint - .');
  test('test-helper.js should pass jshint', function() { 
    ok(true, 'test-helper.js should pass jshint.'); 
  });

});
define('dummy/tests/unit/components/growl-instance-test', ['ember', 'ember-qunit'], function (Ember, ember_qunit) {

  'use strict';

  var testNotification = { options: { type: "error", twitch: true } };

  ember_qunit.moduleForComponent("growl-instance", "Growl Instance");

  ember_qunit.test("assert that the element class exists", function () {
    expect(1);

    ok(this.subject().classNames.indexOf("growl-instance") > -1, "CSS class exists");
  });

  ember_qunit.test("assert that the instance will close when clicked", function () {
    expect(3);

    var subject = this.subject();
    subject.set("notification", testNotification);
    subject.sendAction = function (name, value) {
      equal(name, "action", "The parent action was called");
      equal(value, testNotification, "The notification is passed to the parent action");
    };

    subject.click();

    // now override destroyAlert to make sure it is what called the action
    subject.destroyAlert = function () {
      ok(true, "The instance was closed");
    };

    subject.click();
  });

});
define('dummy/tests/unit/components/growl-instance-test.jshint', function () {

  'use strict';

  module('JSHint - unit/components');
  test('unit/components/growl-instance-test.js should pass jshint', function() { 
    ok(true, 'unit/components/growl-instance-test.js should pass jshint.'); 
  });

});
define('dummy/tests/unit/components/growl-manager-test', ['ember', 'ember-qunit'], function (Ember, ember_qunit) {

  'use strict';

  ember_qunit.moduleForComponent("growl-manager", "Growl Manager");

  ember_qunit.test("assert that the element class exists", function () {
    expect(1);

    ok(this.subject().classNames.indexOf("growl-manager") > -1, "CSS class exists");
  });

  ember_qunit.test("assert that the dismiss action removes the notification", function () {
    expect(2);
    var manager = this.subject(),
        testObject = { name: "test" };

    manager.set("notifications", [testObject]);
    equal(manager.get("notifications.length"), 1, "The message is displayed");
    manager._actions.dismiss.call(manager, testObject);
    equal(manager.get("notifications.length"), 0, "The message has been removed");
  });

});
define('dummy/tests/unit/components/growl-manager-test.jshint', function () {

  'use strict';

  module('JSHint - unit/components');
  test('unit/components/growl-manager-test.js should pass jshint', function() { 
    ok(true, 'unit/components/growl-manager-test.js should pass jshint.'); 
  });

});
define('dummy/tests/unit/services/growl-test', ['ember', 'ember-qunit', 'dummy/services/growl'], function (Ember, ember_qunit, Growl) {

  'use strict';

  module("Growl Service");

  ember_qunit.test("growl is an Ember object with a notification array", function () {
    expect(2);

    ok(Growl['default'].create() instanceof Ember['default'].Object);
    ok(Ember['default'].typeOf(Growl['default'].create().get("notifications")) === "array");
  });

  ember_qunit.test("growl displays the correct type of message for each method", function () {
    expect(9);

    ["error", "alert", "info"].forEach(function (type) {
      var growl = Growl['default'].create({ notifications: [] });
      growl[type]("Uh oh.");
      equal(growl.get("notifications.length"), 1);
      equal(growl.get("notifications.firstObject.content"), "Uh oh.");
      equal(growl.get("notifications.firstObject.options.type"), type);
    });
  });

  ember_qunit.test("the is{type} computed properties are correct and the messages are in order", function () {
    expect(3);

    var growl = Growl['default'].create({ notifications: [] });
    growl.error("Uh oh.");
    growl.info("Meh.");
    growl.alert("RUN!");

    ok(growl.get("notifications").objectAt(0).get("isError"), "isError is true");
    ok(growl.get("notifications").objectAt(1).get("isInfo"), "isInfo is true");
    ok(growl.get("notifications").objectAt(2).get("isAlert"), "isAlert is true");
  });

  ember_qunit.test("assert that the notifications are not duplicated if identical", function () {
    expect(2);

    var growl = Growl['default'].create({ notifications: [] });
    growl.error("NOOOO0000ooooo.....");
    growl.alert("Hi Jerel!");
    equal(growl.get("notifications.length"), 2);
    growl.alert("Hi Jerel!");
    equal(growl.get("notifications.length"), 2);
  });

  ember_qunit.test("assert that default options are present", function () {
    expect(5);
    var growl = Growl['default'].create({ notifications: [] }),
        options = {
      type: "error",
      fadeIn: true,
      closeIn: 5000,
      clickToDismiss: false,
      twitch: false
    };

    growl.error("Test");

    for (var key in options) {
      equal(growl.get("notifications.firstObject.options." + key), options[key]);
    }
  });

  ember_qunit.test("assert that options can be changed from the defaults", function () {
    expect(3);
    var growl = Growl['default'].create({ notifications: [] });

    growl.info("Hello.", { fadeIn: false, twitch: true });

    equal(growl.get("notifications.firstObject.options.closeIn"), 5000, "closeIn is still at default setting");
    equal(growl.get("notifications.firstObject.options.fadeIn"), false, "fadeIn has been set");
    equal(growl.get("notifications.firstObject.options.twitch"), true, "twitch has been set");
  });

});
define('dummy/tests/unit/services/growl-test.jshint', function () {

  'use strict';

  module('JSHint - unit/services');
  test('unit/services/growl-test.js should pass jshint', function() { 
    ok(true, 'unit/services/growl-test.js should pass jshint.'); 
  });

});
/* jshint ignore:start */

define('dummy/config/environment', ['ember'], function(Ember) {
  var prefix = 'dummy';
/* jshint ignore:start */

try {
  var metaName = prefix + '/config/environment';
  var rawConfig = Ember['default'].$('meta[name="' + metaName + '"]').attr('content');
  var config = JSON.parse(unescape(rawConfig));

  return { 'default': config };
}
catch(err) {
  throw new Error('Could not read config from meta tag with name "' + metaName + '".');
}

/* jshint ignore:end */

});

if (runningTests) {
  require("dummy/tests/test-helper");
} else {
  require("dummy/app")["default"].create({"name":"ember-cli-growl","version":"1.0.1.636fcd84"});
}

/* jshint ignore:end */
//# sourceMappingURL=dummy.map